@@ -21,7 +21,7 @@
 		return()
 	}
 	savedig <- options(digits = digits)
-    	
+
 	on.exit(options(savedig))
 	
 	coef <- x$coef
@@ -32,23 +32,27 @@
 #		x$varH<-matrix(x$varH) 
 #		x$varHIH<-matrix(x$varHIH)
 #	}
-#AD:     
-	if (x$typeof == 0){	 
+#AD:
+	if (x$typeof == 0){
 		if (x$n.knots.temp < 4){
 			cat("\n")
-			cat("  The minimum number of knots is 4","\n")	
+			cat("  The minimum number of knots is 4","\n")
 			cat("\n")
-		} 
+		}
 		if (x$n.knots.temp > 20){
 			cat("\n")
-			cat("  The maximum number of knots is 20","\n")	
-		}  
+			cat("  The maximum number of knots is 20","\n")
+		}
 	}else{
 		if ((x$typeof == 1) & (x$indic.nb.int1 == 1)) cat("  The maximum number of time intervals is 20","\n")
-	}   
-#AD     
+	}
+#AD
+
+	if (x$logNormal == 0) frail <- x$theta
+	else frail <- x$sigma2
+
 	if (x$istop == 1){
-		if (!is.null(coef)){ 
+		if (!is.null(coef)){
 			if(x$nvar != 1){
 				seH <- sqrt(diag(x$varH))
 				seHIH <- sqrt(diag(x$varHIH))
@@ -65,16 +69,19 @@
 			}
 		
 			cat("\n")
-			if (!is.null(x$theta)){
-			
-				cat("  Shared Gamma Frailty model parameter estimates ","\n")
+			if (!is.null(frail)){
+				if (x$logNormal == 0){
+					cat("  Shared Gamma Frailty model parameter estimates ","\n")
+				}else{
+					cat("  Shared Log-Normal Frailty model parameter estimates ","\n")
+				}
 				if (x$typeof == 0){
 					cat("  using a Penalized Likelihood on the hazard function","\n")
 				}else{
 					cat("  using a Parametrical approach for the hazard function","\n")
 				}
 		
-				if (x$n.strat>1) cat("  (Stratification structure used)", "\n")         
+				if (x$n.strat>1) cat("  (Stratification structure used)", "\n")
 			}else{
 				if (x$typeof == 0){
 					cat("  Cox proportional hazards model parameter estimates ","\n")
@@ -82,9 +89,9 @@
 				}else{
 					cat("  Cox proportional hazards model parameter estimates ","\n")
 					cat("  using a Parametrical approach for the hazard function","\n")
-				}	
+				}
 				
-				if (x$n.strat>1) cat("  (Stratification structure used)", "\n")         
+				if (x$n.strat>1) cat("  (Stratification structure used)", "\n")
 			}
 			
 			if (x$typeof == 0){
@@ -93,7 +100,7 @@
 					
 				}
 
-				dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)", 
+				dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)",
 				"SE coef (H)", "SE coef (HIH)", "z", "p"))
 
 			}else{
@@ -101,7 +108,7 @@
 					dimnames(tmpwald) <- list(x$names.factor,c("chisq", "df", "global p"))
 					
 				}
-				dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)", 
+				dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)",
 				"SE coef (H)", "z", "p"))
 
 			}
@@ -112,37 +119,48 @@
 				prmatrix(tmpwald)
 			}
 			cat("\n")
-		} 
+		}
 	
-		if (!is.null(x$theta)) {
-			tetha <- x$theta
+		if (!is.null(frail)) {
+			#tetha <- x$theta
 			temp <- x$varTheta[1]
-			seH <- sqrt(((2 * (tetha^0.5))^2) * temp)
+			seH <- sqrt(((2 * (frail^0.5))^2) * temp)
 			temp <- x$varTheta[2]
-			seHIH <- sqrt(((2 * (tetha^0.5))^2) * temp)
+			seHIH <- sqrt(((2 * (frail^0.5))^2) * temp)
 			
 			
 #AD:
 			if (x$noVar1 == 1){
 				cat("\n")
-				cat("    Shared Gamma Frailty model: No covariates \n")
+				if (x$logNormal == 0){ cat("    Shared Gamma Frailty model: No covariates \n") }
+				else { cat("    Shared Log-Normal Frailty model: No covariates \n") }
 				cat("    -------------------------- \n")
 				cat("\n")
 			}
-#AD:		  
+#AD:
 			if (x$typeof == 0){
-				cat("    Frailty parameter, Theta:", tetha, "(SE (H):", 
-				seH, ")", "(SE (HIH):", seHIH, ")", "\n")
+				if (x$logNormal == 0){
+					cat("    Frailty parameter, Theta:", frail, "(SE (H):",
+					seH, ")", "(SE (HIH):", seHIH, ")", "\n")
+				}else{
+					cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
+					seH, ")", "(SE (HIH):", seHIH, ")", "\n")
+				}
 			}else{
-				cat("    Frailty parameter, Theta:", tetha, "(SE (H):", 
-				seH, ")", "\n")
+				if (x$logNormal == 0){
+					cat("    Frailty parameter, Theta:", frail, "(SE (H):",
+					seH, ")", "\n")
+				}else{
+					cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
+					seH, ")", "\n")
+				}
 			}
 			
         	}
-		cat(" \n")     
+		cat(" \n")
 #AD:	
 		if (x$typeof == 0){
-			cat(paste("      penalized marginal log-likelihood =", round(x$logLikPenal,2)))	
+			cat(paste("      penalized marginal log-likelihood =", round(x$logLikPenal,2)))
 			cat("\n")
 			cat("      LCV = the approximate likelihood cross-validation criterion\n")
 			cat("            in the semi parametrical case     =",x$LCV,"\n")
@@ -156,10 +174,10 @@
 			if (x$typeof == 2){
 				cat("\n")
 				if (x$n.strat == 1){
-					cat("      Scale for the weibull hazard function is :",round(x$shape.weib[1],2),"\n")	
-					cat("      Shape for the weibull hazard function is :",round(x$scale.weib[1],2),"\n")
+					cat("      Scale for the weibull hazard function is :",round(x$scale.weib[1],2),"\n")
+					cat("      Shape for the weibull hazard function is :",round(x$shape.weib[1],2),"\n")
 				}else{
-					cat("      Scale for the weibull hazard function is :",round(x$scale.weib[1],2),round(x$scale.weib[2],2),"\n")	
+					cat("      Scale for the weibull hazard function is :",round(x$scale.weib[1],2),round(x$scale.weib[2],2),"\n")
 					cat("      Shape for the weibull hazard function is :",round(x$shape.weib[1],2),round(x$shape.weib[2],2),"\n")
 				}
 					cat("\n")
@@ -198,8 +216,8 @@
 			}
 		
 			if (x$cross.Val){
-				if (is.null(x$theta)){
-					cat("      Smoothing parameter estimated by Cross validation: ", x$kappa[1])  
+				if (is.null(frail)){
+					cat("      Smoothing parameter estimated by Cross validation: ", x$kappa[1])
 				}else{ 
 					cat("      Best smoothing parameter estimated by")
 					cat("\n")
@@ -209,22 +227,27 @@
 			cat(", DoF: ", formatC(-x$DoF, format="f",digits=2))
 		}
 	}else{
-		if (!is.null(x$theta)){
-			cat("  Shared Gamma Frailty model parameter estimates ","\n")
+		if (!is.null(frail)){
+			if (x$logNormal == 0){
+				cat("  Shared Gamma Frailty model parameter estimates ","\n")
+			}else{
+				cat("  Shared Log-Normal Frailty model parameter estimates ","\n")
+			}
 			if (x$typeof == 0){
 				cat("  using a Penalized Likelihood on the hazard function","\n")
 			}else{
 				cat("  using a Parametrical approach for the hazard function","\n")
 			}
 
-			if (x$n.strat>1) cat("  (Stratification structure used)", "\n")   
+			if (x$n.strat>1) cat("  (Stratification structure used)", "\n")
 			if (x$noVar1 == 1){
 				cat("\n")
-				cat("    Shared Gamma Frailty model: No covariates \n")
+				if (x$logNormal == 0){ cat("    Shared Gamma Frailty model: No covariates \n") }
+				else { cat("    Shared Log-Normal Frailty model: No covariates \n") }
 				cat("    -------------------------- \n")
 				cat("\n")
 			}
-				
+
 		}else{
 			if (x$typeof == 0){
 				cat("  Cox proportional hazards model parameter estimates ","\n")
@@ -232,9 +255,9 @@
 			}else{
 				cat("  Cox proportional hazards model parameter estimates ","\n")
 				cat("  using a Parametrical approach for the hazard function","\n")
-			}	
+			}
 			
-			if (x$n.strat>1) cat("  (Stratification structure used)", "\n")         
+			if (x$n.strat>1) cat("  (Stratification structure used)", "\n")
 		}
 		cat("\n")
 		cat("      n=", x$n)
@@ -244,7 +267,7 @@
 		}else{
 			cat("\n")
 		}
-		
+
 		cat("      n events=", x$n.event, " n groups=", x$groups)
 		cat( "\n")
 		cat("      number of iterations: ", x$n.iter)
