@@ -11,7 +11,9 @@ cat("frailtypack test for joint model ...\n")
 ### JOINT frailty model with gap times
 #########################################################################
 
-modJoint.gap <- frailtyPenal( Surv(time,event)~ cluster(id) +
+data("readmission")
+
+gap <- frailtyPenal( Surv(time,event)~ cluster(id) +
   dukes + charlson + sex + chemo + terminal(death),
   formula.terminalEvent = ~ dukes + charlson + sex + chemo,
   data = readmission, n.knots = 8, kappa1 = 2.11e+08, kappa2 = 9.53e+11,
