@@ -1,12 +1,133 @@
+!==========================  DISTANCE   =================================
+
+	subroutine distancessplines(nz1,nz2,b,effet,mt,x1Out,lamOut,suOut,x2Out,lam2Out,su2Out)
+
+	use tailles,only:ndatemax,npmax,NSUJETMAX
+	use comon,only:date,zi,t0,t1,c,nt0,nt1,nsujet,nva,ndate, &
+	nst,I_hess,H_hess,Hspl_hess,hess
+
+	implicit none
+
+	integer::nz1,nz2,i,j,n,np,k,l,effet,mt
+	double precision::x1,x2,h,su,bsup,binf,lam,lbinf, &
+	lbsup
+	double precision,dimension(npmax,npmax)::hes1,hes2
+	double precision,dimension(-2:npmax)::the1,the2
+	double precision,dimension(npmax)::b
+	double precision,dimension(mt,3)::lamOut,suOut,lam2Out,su2Out
+	double precision,dimension(mt)::x1Out,x2Out
+
+
+	n  = nz1+2
+	if(nst.eq.2)then 
+		np  = nz1+2+nz2+2+effet+nva
+	else
+		np  = nz1+2+effet+nva
+	endif
+
+	do i=1,nz1+2
+		do j=1,nz1+2
+			hes1(i,j)=hess(i,j)
+		end do
+	end do 
+
+	if(nst.eq.2)then
+		k = 0
+		do i=nz1+3,nz1+2+nz2+2
+			k = k + 1 
+			l = 0
+			do j=nz1+3,nz1+2+nz2+2
+				l = l + 1
+				hes2(k,l)=hess(i,j)
+			end do
+		end do
+	endif
+
+	do i=1,nz1+2
+		the1(i-3)=(b(i))*(b(i))
+	end do
+	if(nst.eq.2)then
+		do i=1,nz2+2
+			j = nz1+2+i
+			the2(i-3)=(b(j))*(b(j))
+		end do
+	endif
+
+	h = (zi(n)-zi(1))*0.01d0
+	x1 = zi(1)
+	x2 = zi(1)
+
+	do i=1,mt
+		
+		if(i .ne.1)then
+			x1 = x1 + h
+		end if
+		call cosps(x1,the1,nz1+2,hes1,zi,binf,su,bsup,lbinf,lam,lbsup)
+		if(bsup.lt.0.d0)then
+			bsup = 0.d0
+		endif
+		if(binf.gt.1.d0)then
+			binf = 1.d0
+		endif
+		if(lbinf.lt.0.d0)then
+			lbinf = 0.d0
+		endif
+
+!   Replaced by next sentences and add new ones JRG January 05
+!
+!
+		x1Out(i)=x1
+		lamOut(i,1)=lam
+		lamOut(i,2)=lbinf
+		lamOut(i,3)=lbsup
+		suOut(i,1)=su
+
+		suOut(i,2)=binf
+		suOut(i,3)=bsup
+
+
+		if(nst.eq.2)then
+			if(i.ne.1)then
+				x2 = x2 + h
+			endif
+			call cosps(x2,the2,nz2+2,hes2,zi,binf,su,bsup,lbinf,lam,lbsup)
+			if(bsup.lt.0.d0)then
+				bsup = 0.d0
+			endif
+			if(binf.gt.1.d0)then
+				binf = 1.d0
+			endif
+			if(lbinf.lt.0.d0)then
+				lbinf = 0.d0
+			endif
+
+			x2Out(i)=x2
+			lam2Out(i,1)=lam
+			lam2Out(i,2)=lbinf
+			lam2Out(i,3)=lbsup
+			su2Out(i,1)=su
+			su2Out(i,2)=binf
+			su2Out(i,3)=bsup
+		endif
+	end do
+
+	return
+
+	end subroutine distancessplines
+
+!=========================================================================================================
+!=========================================================================================================
+!=========================================================================================================
+!=========================================================================================================
 
 	subroutine distancecpm(b,m,mt,xR1,moyLamR1,xSu1,moysuR1,xR2,moyLamR2,xSu2,moysuR2)
-	
+
 	use tailles
 	use comon,only:cens,vvv,t0,t1,c,nsujet,nva,nva1,nva2,nst,nbrecu,nbintervR,ttt,date
 	use optim
-	
+
 	implicit none
-	
+
 	integer::m,i,j,ier,t,k,gg,jj,uu,ii,ncur,l,mt
 	double precision::sx,som,som11R,som21R,som11RW,som21RW, &
 	glRW,x
@@ -16,9 +137,9 @@
 	double precision,dimension(1000)::lamR,suR,glR	
 	double precision,dimension((m*(m+1)/2))::vv
 	double precision,dimension(nbintervR)::tempsR
-	
+
 	double precision::lamR25,suR25,lamR975,suR975, &
-	LamRW,suRW	
+	LamRW,suRW
 !AD: sorties
 	double precision::ep
 	double precision,dimension(mt)::xR1,xR2
@@ -26,20 +147,19 @@
 	double precision,dimension(100)::xSu1,xSu2
 	double precision,dimension(100,3)::moysuR1,moysuR2
 
-	
 
 	sx=1.d0 ! ecart-type ou variance des réalisations gaussiennes générées
 	uu=0
 	do i=1,nbintervR
 		tempsR(i)=(ttt(i-1)+ttt(i))/(2.d0)
 	end do
-	
+
 	do i=1,m*(m+1)/2
 		vv(i)=vvv(i)
 	end do
 
-!AD: ep=10.d-10 
-   	ep=10.d-10
+!AD: ep=10.d-10
+	ep=10.d-10
 	call dmfsdj(vv,m,ep,ier)
 
 !      ns=m-nva-3! ns est le nombre de paramètres intervenat dans la fonctionde
@@ -53,26 +173,26 @@
 	ncur = 1
 
 !!!!!!!!    HAZ     !!!!!!!!!!
-!!!!!!!! 	
+!!!!!!!!
 	do t=1,nbintervR
 		lamR=0.d0
 		glR=0.d0
-   
+
 !         n=n+1 ! compteur sur nième temps
 		x=tempsR(t)
 ! On simule 1000 réalisations gaussienne par paramètres
 		do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 			do i=1,nbintervR
 				som=0.d0
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
-					call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+					call bgos(SX,0,u(k,j),v(k,j),0.d0)
 					som=som+vv(i*(i-1)/2+j)*u(k,j)
 				end do
 				bgen(i)=(b(i)+som)**2
 			end do              ! en sortie on récupère le nouveau vecteur b
 
-                      
+
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -80,14 +200,14 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
 
 			lamR(k)=0.d0
 			lamRW=0.d0
 
 			do gg=1,nbintervR
-				if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then				
+				if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then
 					lamR(k)=bgen(gg)
 				endif
 			end do
@@ -98,14 +218,14 @@
 				endif
 			end do
 			
-            
+
 		end do
-	
+
 ! Classer les différent vecteur et en sortir les 2.5 et 97.5 percentiles
 
 		call percentile(lamR,lamR25,lamR975)
-	
-	
+
+
 		do ii=1,nbintervR
 			if (x.gt.ttt(ii-1).and.x.lt.ttt(ii))then
 				uu=ii
@@ -115,31 +235,31 @@
 			xR1(ncur) = real(ttt(uu-1))
 		else
 			xR1=date(1)
-		end if	
+		end if
 		xR1(ncur+1) = real(x)
 		xR1(ncur+2) = real(ttt(uu))
-		
+
 		moyLamR1(ncur,1) = real(LamRW)
 		moyLamR1(ncur+1,1) = moyLamR1(ncur,1)
-		moyLamR1(ncur+2,1) = moyLamR1(ncur,1)	
-		
+		moyLamR1(ncur+2,1) = moyLamR1(ncur,1)
+
 		moyLamR1(ncur,2) = real(lamR25)
 		moyLamR1(ncur+1,2) = moyLamR1(ncur,2)
 		moyLamR1(ncur+2,2) = moyLamR1(ncur,2)
-		
-		
+
+
 		moyLamR1(ncur,3) = real(lamR975)
 		moyLamR1(ncur+1,3) = moyLamR1(ncur,3)
 		moyLamR1(ncur+2,3) = moyLamR1(ncur,3)
-		
+
 
 		ncur=ncur+3
 
 	end do
 
-!
+
 !!!! SURV 1
-	
+
 	bgen=0.d0
 	x=date(1)
 	do t=1,100
@@ -150,12 +270,12 @@
 			do i=1,nbintervR
 				som=0.d0
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
-					call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+					call bgos(SX,0,u(k,j),v(k,j),0.d0)
 					som=som+vv(i*(i-1)/2+j)*u(k,j)
 				end do
 				bgen(i)=(b(i)+som)**2
 
-			end do 	
+			end do
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -163,55 +283,55 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)  		
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
 			som11R=0.d0
-			som21R=0.d0	
+			som21R=0.d0
 			glR(k)=0.d0
-			suR(k)=0.d0	
-				
+			suR(k)=0.d0
+
 			do gg=1,nbintervR
 				if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then
-				
+
 					som11R=bgen(gg)*(x-ttt(gg-1))
-					
+
 					if (gg.ge.2)then
 						do jj=1,gg-1
 							som21R=som21R+bgen(jj)*(ttt(jj)-ttt(jj-1))
 						end do
 					endif
-					
+
 					glR(k)=(som11R+som21R)
 					suR(k)=dexp(-glR(k))
 				endif
 			end do
 			
 		end do
-		
+
 		som11RW=0.d0
 		som21RW=0.d0
 		glRW=0.d0
 		suRW=0.d0
 		do l=1,nbintervR
 			if ((x.ge.(ttt(l-1))).and.(x.lt.(ttt(l)))) then
-			
+
 				som11RW=(b(l)**2)*(x-ttt(l-1))
-				
+
 				if (l.ge.2)then
 					do jj=1,l-1
 					som21RW=som21RW+(b(jj)**2)*(ttt(jj)-ttt(jj-1))
 					end do
 				endif
-				
+
 				glRW=(som11RW+som21RW)
 				suRW=dexp(-glRW)
 			endif
-		end do	
-		
+		end do
+
 		suR25=0.d0
 		suR975=0.d0
 		call percentile(suR,suR25,suR975)
-		if(t.ne.1) then 
+		if(t.ne.1) then
 			xSu1(t) = real(x)
 		else
 			xSu1(t)=date(1)
@@ -223,34 +343,34 @@
 		moysuR1(t,2) = suR25
 
 		moysuR1(t,3) = suR975
-		
+
 		if(moysuR1(t,1).lt.0.d0)then
 			moysuR1(t,1) = 0.d0
 		endif
 		if(moysuR1(t,1).gt.1.d0)then
-			moysuR1(t,1) = 1.d0 
+			moysuR1(t,1) = 1.d0
 		endif
-		
+
 		if(moysuR1(t,2).lt.0.d0)then
 			moysuR1(t,2) = 0.d0
 		endif
 		if(moysuR1(t,2).gt.1.d0)then
-			moysuR1(t,2) = 1.d0 
-		endif	
+			moysuR1(t,2) = 1.d0
+		endif
 		if(moysuR1(t,3).lt.0.d0)then
 			moysuR1(t,3) = 0.d0
 		endif
 		if(moysuR1(t,3).gt.1.d0)then
-			moysuR1(t,3) = 1.d0 
-		endif			
+			moysuR1(t,3) = 1.d0
+		endif
 	end do
 !!!!!!!   FIN SURV     !!!!!!!!!!
 
 !!!! HAZ 2
 !!!!
 
-	
-	if (nst == 2) then	
+
+	if (nst == 2) then
 
 		ncur = 1
 
@@ -261,11 +381,11 @@
 			x=tempsR(t)
 ! On simule 1000 réalisations gaussienne par paramètres
 			do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 				do i=nbintervR+1,nbintervR*nst
 					som=0.d0
 					do j=1,i         ! cela correspond au produit trp(L)%*%U
-						call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+						call bgos(SX,0,u(k,j),v(k,j),0.d0)
 						som=som+vv(i*(i-1)/2+j)*u(k,j)
 					end do
 
@@ -280,32 +400,32 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
-	
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
+
 				lamR(k)=0.d0
 				lamRW=0.d0
-	
+
 				do gg=1,nbintervR
-					if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then				
+					if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then
 						lamR(k)=bgen(gg)
 					endif
 				end do
-	
+
 				do l=1,nbintervR
 					if ((x.ge.(ttt(l-1))).and.(x.lt.(ttt(l)))) then
 						lamRW=b(l+nbintervR)**2
 					endif
 				end do
-				
-		
+
+
 			end do
-	
+
 ! Classer les différent vecteur et en sortir les 2.5 et 97.5 percentiles
 
 			call percentile(lamR,lamR25,lamR975)
-		
-		
+
+
 			do ii=1,nbintervR
 				if (x.gt.ttt(ii-1).and.x.lt.ttt(ii))then
 					uu=ii
@@ -315,18 +435,18 @@
 				xR2(ncur) = real(ttt(uu-1))
 			else
 				xR2=date(1)
-			end if		
+			end if
 			xR2(ncur+1) = real(x)
 			xR2(ncur+2) = real(ttt(uu))
-			
+
 			moyLamR2(ncur,1) = real(LamRW)
 			moyLamR2(ncur+1,1) = moyLamR2(ncur,1)
-			moyLamR2(ncur+2,1) = moyLamR2(ncur,1)	
-			
+			moyLamR2(ncur+2,1) = moyLamR2(ncur,1)
+
 			moyLamR2(ncur,2) = real(lamR25)
 			moyLamR2(ncur+1,2) = moyLamR2(ncur,2)
 			moyLamR2(ncur+2,2) = moyLamR2(ncur,2)
-			
+
 			moyLamR2(ncur,3) = real(lamR975)
 			moyLamR2(ncur+1,3) = moyLamR2(ncur,3)
 			moyLamR2(ncur+2,3) = moyLamR2(ncur,3)
@@ -340,37 +460,37 @@
 			if(t .ne. 1) then
 				x=x+ttt(nbintervR)/100
 			end if
-			
+
 			do k=1,1000
 				do i=nbintervR+1,nbintervR*nst
 					som=0.d0
 					do j=1,i         ! cela correspond au produit trp(L)%*%U
-						call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+						call bgos(SX,0,u(k,j),v(k,j),0.d0)
 						som=som+vv(i*(i-1)/2+j)*u(k,j)
 					end do
-					if(bgen(i-nbintervR).gt.(1.d0)) then 
-						bgen(i-nbintervR)=1.d0 
+					if(bgen(i-nbintervR).gt.(1.d0)) then
+						bgen(i-nbintervR)=1.d0
 					else
 						bgen(i-nbintervR)=(b(i)+som)**2
 					endif
-				end do 	
-	
+				end do
+
 				som11R=0.d0
-				som21R=0.d0	
+				som21R=0.d0
 				glR(k)=0.d0
-				suR(k)=0.d0	
-	
+				suR(k)=0.d0
+
 				do gg=1,nbintervR
 					if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then
-					
+
 						som11R=bgen(gg)*(x-ttt(gg-1))
-						
+
 						if (gg.ge.2)then
 							do jj=1,gg-1
 								som21R=som21R+bgen(jj)*(ttt(jj)-ttt(jj-1))
 							end do
 						endif
-						
+
 						glR(k)=(som11R+som21R)
 						suR(k)=dexp(-glR(k))
 					endif
@@ -384,9 +504,9 @@
 
 			do l=1,nbintervR
 				if ((x.ge.(ttt(l-1))).and.(x.lt.(ttt(l)))) then
-!				
+
 					som11RW=(b(l+nbintervR)**2)*(x-ttt(l-1))
-!					
+
 					if (l.ge.2)then
 						do jj=1,l-1
 							som21RW=som21RW+(b(jj+nbintervR)**2)*(ttt(jj)-ttt(jj-1))
@@ -395,45 +515,45 @@
 					glRW=(som11RW+som21RW)
 					suRW=dexp(-glRW)
 				endif
-			end do	
+			end do
 			suR25=0.d0
 			suR975=0.d0
 			call percentile(suR,suR25,suR975)
-			if(t.ne.1) then 
+			if(t.ne.1) then
 				xSu2(t) = real(x)
 			else
 				xSu2(t)=date(1)
-			end if	
+			end if
 			moysuR2(t,1) = suRW
 			moysuR2(t,2) = suR25
 			moysuR2(t,3) = suR975
-			
+
 			if(moysuR2(t,1).lt.0.d0)then
 				moysuR2(t,1) = 0.d0
 			endif
 			if(moysuR2(t,1).gt.1.d0)then
-				moysuR2(t,1) = 1.d0 
+				moysuR2(t,1) = 1.d0
 			endif
-			
+
 			if(moysuR2(t,2).lt.0.d0)then
 				moysuR2(t,2) = 0.d0
 			endif
 			if(moysuR2(t,2).gt.1.d0)then
-				moysuR2(t,2) = 1.d0 
-			endif	
+				moysuR2(t,2) = 1.d0
+			endif
 			if(moysuR2(t,3).lt.0.d0)then
 				moysuR2(t,3) = 0.d0
 			endif
 			if(moysuR2(t,3).gt.1.d0)then
-				moysuR2(t,3) = 1.d0 
-			endif	
+				moysuR2(t,3) = 1.d0
+			endif
 		end do
 	end if
 
 	end subroutine distancecpm
 
 !=========================================================================================================
-!=========================================================================================================	
+!=========================================================================================================
 !=========================================================================================================
 !=========================================================================================================
 
@@ -449,7 +569,7 @@
 	integer,intent(in)::m,mt
 	integer::i,j,ier,t,k,ns
 	double precision::lamR25,lamDC25,suR25,suDC25,lamR975,lamDC975,suR975,suDC975, &
-	LamRW,LamDCW,suRW,suDCW      
+	LamRW,LamDCW,suRW,suDCW
         double precision,dimension(m*(m+1)/2)::vv
 	double precision,dimension(m)::b,bgen
 	double precision,dimension(1000,m)::u
@@ -466,7 +586,7 @@
 
 
 
-		
+
 	lamR25=0.d0
 	lamDC25=0.d0
 	suR25=0.d0
@@ -484,14 +604,14 @@
 	k=0
 	ns=0
 	sx=1.d0 ! ecart-type ou variance des réalisations gaussiennes générées
-	!typeof2 = 1 shared weib 
+	!typeof2 = 1 shared weib
 	if (typeof2 == 1) then
 		ns=m-nva-1
 	end if
-	!typeof2 = 2  weib 
+	!typeof2 = 2  weib
  	if (typeof2 == 2) then
 		ns=m-nva-2
-	end if    
+	end if
 	
 	do i=1,ns*(ns+1)/2
 		vv(i)=vvv(i)
@@ -501,7 +621,7 @@
 	call dmfsdj(vv,m,ep,ier)
 
 	do k=1,1000!0
-		do j=1,ns   
+		do j=1,ns
 			call bgos(SX,0,zz,zy,0.d0)
 			u(k,j)=zz
 		end do
@@ -509,7 +629,7 @@
 
 
 !     Pour chaque temps de 0 à la censure du décès par pas cens/100
-	
+
  !     commencer à 0 dans la boucle
 	x=date(1)
 !       shape et scale
@@ -525,7 +645,7 @@
 	end if
 
 	do t=1,mt
-		
+
 		lamR=0.d0
 		lamDC=0.d0
 !         n=n+1 ! compteur sur nième temps
@@ -535,7 +655,7 @@
 
 ! On simule 1000 réalisations gaussienne par paramètres
 		do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 			do i=1,ns
 				som=0.d0
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
@@ -543,10 +663,10 @@
 				end do
 				bgen(i)=(b(i)+som)**2
 			end do              ! en sortie on récupère le nouveau vecteur b
-			
 
 
-!            Moybgen(k)=Moybgen(k)+bgen(i)/1000          
+
+!            Moybgen(k)=Moybgen(k)+bgen(i)/1000
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -554,25 +674,25 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
-			
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
+
 			lamR(k)=(bgen(1)*(x**(bgen(1)-1.d0)))/(bgen(2)**bgen(1))
 			lamRW=((b(1)**2)*(x**((b(1)**2)-1.d0)))/((b(2)**2)**(b(1)**2))
-			
+
 			if(nst == 2) then
 				lamDC(k)=(bgen(3)*(x**(bgen(3)-1.d0)))/(bgen(4)**bgen(3))
 				lamDCW=((b(3)**2)*(x**((b(3)**2)-1.d0)))/((b(4)**2)**(b(3)**2))
 			end if
 		end do
-            		
+
 ! Classer les différent vecteur et en sortir les 2.5 et 97.5 percentiles
 
 		call percentile(lamR,lamR25,lamR975)
 		if(nst == 2) then
 			call percentile(lamDC,lamDC25,lamDC975)
 		end if
-!----- strate 1	
+!----- strate 1
 		if(t == 1) then
 			xR1(t)=date(1)
 		else
@@ -593,17 +713,17 @@
 			xR2(t) = 0.d0
 			moyLamR2(t,1) =  0.d0
 			moyLamR2(t,2) =  0.d0
-			moyLamR2(t,3) =  0.d0	
+			moyLamR2(t,3) =  0.d0
 		end if
-		
+
 	end do
-	
+
 	x=date(1)
 
 	do t=1,100
-		
+
 		glR=0.d0
-		suR=0.d0      
+		suR=0.d0
 		glDC=0.d0
 		suDC=0.d0
 !         n=n+1 ! compteur sur nième temps
@@ -612,7 +732,7 @@
 		end if
 ! On simule 1000 réalisations gaussienne par paramètres
 		do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 			do i=1,ns
 				som=0.d0
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
@@ -620,10 +740,10 @@
 				end do
 				bgen(i)=(b(i)+som)**2
 			end do              ! en sortie on récupère le nouveau vecteur b
-			
 
 
-!            Moybgen(k)=Moybgen(k)+bgen(i)/1000          
+
+!            Moybgen(k)=Moybgen(k)+bgen(i)/1000
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -631,30 +751,30 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
-			
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
+
 			glR(k)  =  (x/bgen(2))**bgen(1)
 			suR(k)  = dexp(-glR(k))
 			glRW  =  (x/(b(2)**2))**(b(1)**2)
 			suRW  = dexp(-glRW)
-						
+
 			if(nst == 2) then
 				glDC(k)  =  (x/bgen(4))**bgen(3)
-				suDC(k)  = dexp(-glDC(k))			
+				suDC(k)  = dexp(-glDC(k))
 				glDCW  =  (x/(b(4)**2))**(b(3)**2)
 				suDCW  = dexp(-glDCW)
 			end if
 
 		end do
-            		
+
 ! Classer les différent vecteur et en sortir les 2.5 et 97.5 percentiles
 
 		call percentile(suR,suR25,suR975)
 		if(nst == 2) then
 			call percentile(suDC,suDC25,suDC975)
 		end if
-		
+
 		if(t==1) then
 			xSu1(t) = date(1)
 		else
@@ -662,27 +782,27 @@
 		end if
 		moysuR1(t,1) = real(suRW)
 		moysuR1(t,2) = real(suR25)
-		moysuR1(t,3) = real(suR975)	
-		
+		moysuR1(t,3) = real(suR975)
+
 		if(moysuR1(t,1).lt.0.d0)then
 			moysuR1(t,1) = 0.d0
 		endif
 		if(moysuR1(t,1).gt.1.d0)then
-			moysuR1(t,1) = 1.d0 
+			moysuR1(t,1) = 1.d0
 		endif
-		
+
 		if(moysuR1(t,2).lt.0.d0)then
 			moysuR1(t,2) = 0.d0
 		endif
 		if(moysuR1(t,2).gt.1.d0)then
-			moysuR1(t,2) = 1.d0 
-		endif	
+			moysuR1(t,2) = 1.d0
+		endif
 		if(moysuR1(t,3).lt.0.d0)then
 			moysuR1(t,3) = 0.d0
 		endif
 		if(moysuR1(t,3).gt.1.d0)then
-			moysuR1(t,3) = 1.d0 
-		endif					
+			moysuR1(t,3) = 1.d0
+		endif
 
 		if(nst == 2) then
 			xSu2(t) = xSu1(t)!real(x)
@@ -693,43 +813,157 @@
 				moysuR2(t,1) = 0.d0
 			endif
 			if(moysuR2(t,1).gt.1.d0)then
-				moysuR2(t,1) = 1.d0 
+				moysuR2(t,1) = 1.d0
 			endif
-			
+
 			if(moysuR2(t,2).lt.0.d0)then
 				moysuR2(t,2) = 0.d0
 			endif
 			if(moysuR2(t,2).gt.1.d0)then
-				moysuR2(t,2) = 1.d0 
+				moysuR2(t,2) = 1.d0
 			endif	
 			if(moysuR2(t,3).lt.0.d0)then
 				moysuR2(t,3) = 0.d0
 			endif
 			if(moysuR2(t,3).gt.1.d0)then
-				moysuR2(t,3) = 1.d0 
+				moysuR2(t,3) = 1.d0
 			endif
 		else
 			xSu2(t) = 0.d0
 			moysuR2(t,1) = 0.d0
 			moysuR2(t,2) = 0.d0
-			moysuR2(t,3) = 0.d0	
+			moysuR2(t,3) = 0.d0
 		end if
 	end do
-		
+
 
 	end subroutine distanceweib
 
+!==========================  DISTANCE   =================================
+
+	subroutine distanceJsplines(nz1,nz2,b,mt1,mt2,x1Out,lamOut,suOut,x2Out,lam2Out,su2Out)
+	
+	use tailles
+	use comon,only:date,datedc,zi,t0,t1,t0dc,t1dc,c,cdc &
+	,nt0,nt1,nt0dc,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst &
+	,PEN_deri,I_hess,H_hess,Hspl_hess,hess
+	
+	Implicit none  
+	
+	
+	integer,intent(in):: nz1,nz2,mt1,mt2
+	double precision ,dimension(npmax),intent(in):: b
+	integer::i,j,n,k,l      
+	double precision::x1,x2,h,su,bsup,binf,lam,lbinf,lbsup
+	double precision ,dimension(npmax,npmax)::hes1,hes2
+	double precision ,dimension(-2:npmax):: the1,the2     
+	double precision,dimension(mt1)::x1Out
+	double precision,dimension(mt2)::x2Out
+	double precision,dimension(mt1,3):: lamOut,suOut
+	double precision,dimension(mt2,3):: lam2Out,su2Out
+		
+	n  = nz1+2
+	do i=1,nz1+2
+		do j=1,nz1+2
+			hes1(i,j)=h_Hess(i,j)
+		end do
+	end do 
+
+	if(nst.eq.2)then  
+		k = 0
+		do i=nz1+3,nz1+2+nz2+2
+			k = k + 1 
+			l = 0
+			do j=nz1+3,nz1+2+nz2+2
+				l = l + 1
+				hes2(k,l)=H_hess(i,j)
+			end do
+		end do   
+	endif
+
+	do i=1,nz1+2
+		the1(i-3)=(b(i))*(b(i))
+	end do
+	if(nst.eq.2)then  
+		do i=1,nz2+2
+			j = nz1+2+i
+			the2(i-3)=(b(j))*(b(j))
+		end do
+	endif
+	h = (zi(n)-zi(1))*0.01d0
+	x1 = zi(1)
+	x2 = zi(1)     
+  
+! Recurrent          
+	do i=1,mt1
+		if(i .ne.1)then
+			x1 = x1 + h 
+		end if
+		call cospJ(x1,the1,nz1+2,hes1,zi,binf,su,bsup,lbinf,lam,lbsup)
+				
+		if(bsup.lt.0.d0)then
+			bsup = 0.d0
+		endif
+		if(binf.gt.1.d0)then
+			binf = 1.d0 
+		endif
+		if(lbinf.lt.0.d0)then
+			lbinf = 0.d0
+		endif 
+!!!   Replaced by next sentences and add new ones JRG January 05
+
+		x1Out(i)=x1
+		lamOut(i,1)=lam
+		lamOut(i,2)=lbinf
+		lamOut(i,3)=lbsup 
+		suOut(i,1)=su
+		suOut(i,2)=bsup
+		suOut(i,3)=binf
+	end do   
+
+! Death  
+	if(nst.eq.2)then        
+		do i=1,mt2
+!!!   Replaced by next sentences and add new ones JRG January 05	
+			if(i.ne.1)then
+				x2 = x2 + h 
+			endif	
+			call cospJ(x2,the2,nz2+2,hes2,zi,binf,su,bsup,lbinf,lam,lbsup)
+			if(bsup.lt.0.d0)then
+				bsup = 0.d0
+			endif
+			if(binf.gt.1.d0)then
+				binf = 1.d0 
+			endif
+			if(lbinf.lt.0.d0)then
+				lbinf = 0.d0
+			endif 
+
+			x2Out(i)=x2
+			lam2Out(i,1)=lam
+			lam2Out(i,2)=lbinf
+			lam2Out(i,3)=lbsup 
+			su2Out(i,1)=su
+			su2Out(i,2)=binf
+			su2Out(i,3)=bsup 
+		end do  
+	endif
+	          
+	return
+		
+	end subroutine distanceJsplines
 
 !====================================================================
+
 	subroutine distancejcpm(b,m,mt1,mt2,x1R,moyLamR,xSu1,moysuR,x2DC,moyLamDC,xSu2,moysuDC)
-	
+
 	use tailles
 	use comon,only:cens,vvv,t0,t1,t0dc,t1dc,c,cdc,nsujet, &
 	nva,nva1,nva2,nst,nbintervR,nbintervDC,ttt,tttDC,date
 	use optim
-	
+
 	implicit none
-	
+
 	integer::m,i,j,ier,t,k,gg,jj,uu,ii,ncur,mt1,mt2,l
 	double precision::sx,som,som11R,som21R,som11RW,som21RW, &
 	glRW,x
@@ -739,7 +973,7 @@
 	double precision,dimension(1000)::lamR,lamDC,suR,glR	
 	double precision,dimension((m*(m+1)/2))::vv
 	double precision,dimension(m)::tempsR,tempsDC
-	
+
 	double precision::lamR25,lamDC25,suR25,lamR975,lamDC975,suR975, &
 	LamRW,LamDCW,suRW
 !AD: sorties
@@ -751,25 +985,25 @@
 	double precision,dimension(mt2,3)::moyLamDC
 	double precision,dimension(100,3)::moysuDC
 	double precision,dimension(100)::xSu1,xSu2
-	
-	
+
+
 	uu=0
 	bgen=0.d0
 	sx=1.d0 ! ecart-type ou variance des réalisations gaussiennes générées
-	
+
 	do i=1,nbintervR
 		tempsR(i)=(ttt(i-1)+ttt(i))/(2.d0)
 	end do
-	
+
 	do i=1,nbintervDC
 		tempsDC(i)=(tttdc(i-1)+tttdc(i))/(2.d0)
 	end do
-      
+
 	do i=1,m*(m+1)/2
 		vv(i)=vvv(i)
 	end do
-!AD: ep=10.d-10 
-   	ep=10.d-10
+!AD: ep=10.d-10
+	ep=10.d-10
 	call dmfsdj(vv,m,ep,ier)
 
 !      ns=m-nva-3! ns est le nombre de paramètres intervenat dans la fonctionde
@@ -785,16 +1019,16 @@
 		x=tempsR(t)
 ! On simule 1000 réalisations gaussienne par paramètres
 		do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 			do i=1,nbintervR!m
 				som=0.d0
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
-					call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+					call bgos(SX,0,u(k,j),v(k,j),0.d0)
 					som=som+vv(i*(i-1)/2+j)*u(k,j)
 				end do
 				bgen(i)=(b(i)+som)**2
 			end do              ! en sortie on récupère le nouveau vecteur b
-                      
+
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -802,8 +1036,8 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
 
 			lamR(k)=0.d0
 			lamRW=0.d0
@@ -815,11 +1049,11 @@
 			end do
 
 			do gg=1,nbintervR
-				if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then	
+				if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then
 					lamRW=b(gg)**2
 				endif
 			end do
-			        
+
 		end do
 
 ! Classer les différent vecteur et en sortir les 2.5 et 97.5 percentiles
@@ -832,52 +1066,52 @@
 			endif
 		end do
 		if(t.ne.1) then 
-			x1R(ncur) = real(ttt(uu-1))	
+			x1R(ncur) = real(ttt(uu-1))
 		else
 			x1R=date(1)
-		end if		
+		end if
 		x1R(ncur+1) = real(x)
 		x1R(ncur+2) = real(ttt(uu))
-		
+
 		moyLamR(ncur,1) = real(LamRW)
 		moyLamR(ncur+1,1) = moyLamR(ncur,1)
 		moyLamR(ncur+2,1) = moyLamR(ncur,1)
-		
+
 		moyLamR(ncur,2) = real(lamR25)
 		moyLamR(ncur+1,2) = moyLamR(ncur,2)
 		moyLamR(ncur+2,2) = moyLamR(ncur,2)
-		
-		
+
+
 		moyLamR(ncur,3) = real(lamR975)
 		moyLamR(ncur+1,3) = moyLamR(ncur,3)
 		moyLamR(ncur+2,3) = moyLamR(ncur,3)
-		
+
 		ncur=ncur+3
 	end do
 
 
 	ncur = 1
-	do t=1,nbintervDC	
+	do t=1,nbintervDC
 		x=tempsDC(t)
 		lamDC=0.d0
 
 !         n=n+1 ! compteur sur nième temps
 ! On simule 1000 réalisations gaussienne par paramètres
 		do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 			do i=1,nbintervDC!m
-			
+
 				som=0.d0
-				
+
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
-					call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+					call bgos(SX,0,u(k,j),v(k,j),0.d0)
 					som=som+vv(i*(i-1)/2+j)*u(k,j)
 				end do
-				
+
 				bgen(i)=(b(nbintervR + i)+som)**2
 			end do              ! en sortie on récupère le nouveau vecteur b
-	
-    
+
+
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -885,31 +1119,30 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
-	
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
+
 			lamDC(k)=0.d0
 			lamDCW=0.d0
-	
+
 			do gg=1,nbintervDC
 				if((x.ge.(tttdc(gg-1))).and.(x.lt.(tttdc(gg))))then
 					lamDC(k)=bgen(gg)
 				endif
-			end do            
+			end do
 
 			do gg=1,nbintervDC
 				if((x.ge.(tttdc(gg-1))).and.(x.lt.(tttdc(gg))))then
 					lamDCW=b(gg+nbintervR)**2
 				endif
-			end do                 
+			end do
 		end do
 
 ! Classer les différent vecteur et en sortir les 2.5 et 97.5 percentiles
 
 		call percentile(lamDC,lamDC25,lamDC975)
-		
 
-		
+
 		do ii=1,nbintervDC
 			if (x.gt.tttdc(ii-1).and.x.lt.tttdc(ii))then
 				uu=ii
@@ -924,23 +1157,23 @@
 		x2DC(ncur+2) = real(tttdc(uu))
 
 		moyLamDC(ncur,1) = real(lamDCW)
-		moyLamDC(ncur+1,1) = moyLamDC(ncur,1)		
-		moyLamDC(ncur+2,1) = moyLamDC(ncur,1)		
-		
+		moyLamDC(ncur+1,1) = moyLamDC(ncur,1)
+		moyLamDC(ncur+2,1) = moyLamDC(ncur,1)
+
 		moyLamDC(ncur,2) = real(lamDC25)
 		moyLamDC(ncur+1,2) = moyLamDC(ncur,2)
 		moyLamDC(ncur+2,2) = moyLamDC(ncur,2)
-						
+
 		moyLamDC(ncur,3) = real(lamDC975)
 		moyLamDC(ncur+1,3) = moyLamDC(ncur,3)
 		moyLamDC(ncur+2,3) = moyLamDC(ncur,3)
-	
+
 		ncur=ncur+3
 	end do
 
 !--------------- Fontion de survie recurrent ----------------
 	bgen=0.d0
-	
+
 	x=date(1)
 
 	do t=1,100
@@ -951,16 +1184,16 @@
 		end if
 ! On simule 1000 réalisations gaussienne par paramètres
 		do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 			do i=1,nbintervR!m
 				som=0.d0
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
-					call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+					call bgos(SX,0,u(k,j),v(k,j),0.d0)
 					som=som+vv(i*(i-1)/2+j)*u(k,j)
 				end do
 				bgen(i)=(b(i)+som)**2
 			end do              ! en sortie on récupère le nouveau vecteur b
-                      
+
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -968,30 +1201,30 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
 
 			som11R=0.d0
-			som21R=0.d0	
+			som21R=0.d0
 			glR(k)=0.d0
 			suR(k)=0.d0
 
 			do gg=1,nbintervR
 				if ((x.ge.(ttt(gg-1))).and.(x.lt.(ttt(gg)))) then
-				
+
 					som11R=bgen(gg)*(x-ttt(gg-1))
-					
+
 					if (gg.ge.2)then
 						do jj=1,gg-1
 							som21R=som21R+bgen(jj)*(ttt(jj)-ttt(jj-1))
 						end do
 					endif
-					
+
 					glR(k)=(som11R+som21R)
 					suR(k)=dexp(-glR(k))
 				endif
 			end do
-       
+
 		end do
 
 		som11RW=0.d0
@@ -1000,15 +1233,15 @@
 		suRW=0.d0
 		do l=1,nbintervR
 			if ((x.ge.(ttt(l-1))).and.(x.lt.(ttt(l)))) then
-			
+
 				som11RW=(b(l)**2)*(x-ttt(l-1))
-				
+
 				if (l.ge.2)then
 					do jj=1,l-1
 						som21RW=som21RW+(b(jj)**2)*(ttt(jj)-ttt(jj-1))
 					end do
 				endif
-				
+
 				glRW=(som11RW+som21RW)
 				suRW=dexp(-glRW)
 			endif
@@ -1028,26 +1261,26 @@
 		moysuR(t,2) = suR25
 
 		moysuR(t,3) = suR975
-		
+
 		if(moysuR(t,1).lt.0.d0)then
 			moysuR(t,1) = 0.d0
 		endif
 		if(moysuR(t,1).gt.1.d0)then
-			moysuR(t,1) = 1.d0 
+			moysuR(t,1) = 1.d0
 		endif
-		
+
 		if(moysuR(t,2).lt.0.d0)then
 			moysuR(t,2) = 0.d0
 		endif
 		if(moysuR(t,2).gt.1.d0)then
-			moysuR(t,2) = 1.d0 
-		endif	
+			moysuR(t,2) = 1.d0
+		endif
 		if(moysuR(t,3).lt.0.d0)then
 			moysuR(t,3) = 0.d0
 		endif
 		if(moysuR(t,3).gt.1.d0)then
-			moysuR(t,3) = 1.d0 
-		endif		
+			moysuR(t,3) = 1.d0
+		endif
 
 	end do
 
@@ -1061,19 +1294,19 @@
 		if(t.ne.1) then
 			x=x+tttdc(nbintervDC)/100
 		end if
-		
+
 ! On simule 1000 réalisations gaussienne par paramètres
 		do k=1,1000
-!     Pour chaque paramètre estimé                         
+!     Pour chaque paramètre estimé
 			do i=1,nbintervDC!m
 				som=0.d0
 				do j=1,i         ! cela correspond au produit trp(L)%*%U
-					call bgos(SX,0,u(k,j),v(k,j),0.d0)  
+					call bgos(SX,0,u(k,j),v(k,j),0.d0)
 					som=som+vv(i*(i-1)/2+j)*u(k,j)
 				end do
 				bgen(i)=(b(i+nbintervR)+som)**2
 			end do              ! en sortie on récupère le nouveau vecteur b
-                      
+
 !     Rappel des notations:
 !     Ce sont les paramètres des fcts de type weibull
 !     betaR= b(1)**2
@@ -1081,35 +1314,32 @@
 !     betaD= b(3)**2
 !     etaD= b(4)**2
 !     fct de risque ou hazard : lam=(betaR*(x**(betaR-1.d0)))/(etaR**betaR)
-!     fct de risque cumulée   : gl  =  (x/etaR)**betaR        
-!     fct de survie           : su  = dexp(-gl)    
+!     fct de risque cumulée   : gl  =  (x/etaR)**betaR
+!     fct de survie           : su  = dexp(-gl)
 
 			som11R=0.d0
-			som21R=0.d0	
+			som21R=0.d0
 			glR(k)=0.d0
 			suR(k)=0.d0
 
 
-
 			do gg=1,nbintervDC
 				if ((x.ge.(tttdc(gg-1))).and.(x.lt.(tttdc(gg)))) then
-				
+
 					som11R=bgen(gg)*(x-tttdc(gg-1))
-					
+
 					if (gg.ge.2)then
 						do jj=1,gg-1
 							som21R=som21R+bgen(jj)*(tttdc(jj)-tttdc(jj-1))
 						end do
 					endif
-					
+
 					glR(k)=(som11R+som21R)
 					suR(k)=dexp(-glR(k))
 				endif
 			end do
 
 
-			           
-		
 !			moysuR0=moysuR0+suR(k)/1000
             
 		end do
@@ -1128,7 +1358,7 @@
 						som21RW=som21RW+(b(jj+nbintervR)**2)*(tttdc(jj)-tttdc(jj-1))
 					end do
 				endif
-				
+
 				glRW=(som11RW+som21RW)
 				suRW=dexp(-glRW)
 			endif
@@ -1149,26 +1379,26 @@
 		moysuDC(t,2) = suR25
 
 		moysuDC(t,3) = suR975
-		
+
 		if(moysuDC(t,1).lt.0.d0)then
 			moysuDC(t,1) = 0.d0
 		endif
 		if(moysuDC(t,1).gt.1.d0)then
-			moysuDC(t,1) = 1.d0 
+			moysuDC(t,1) = 1.d0
 		endif
-		
+
 		if(moysuDC(t,2).lt.0.d0)then
 			moysuDC(t,2) = 0.d0
 		endif
 		if(moysuDC(t,2).gt.1.d0)then
-			moysuDC(t,2) = 1.d0 
-		endif	
+			moysuDC(t,2) = 1.d0
+		endif
 		if(moysuDC(t,3).lt.0.d0)then
 			moysuDC(t,3) = 0.d0
 		endif
 		if(moysuDC(t,3).gt.1.d0)then
-			moysuDC(t,3) = 1.d0 
-		endif	
+			moysuDC(t,3) = 1.d0
+		endif
 
 	end do
 
@@ -1181,29 +1411,29 @@
 	use comon,only:cens,vvv,t0,t1,t0dc,t1dc,c,cdc,nsujet &
 	,nva,nva1,nva2,nst,etaR,etaD,betaR,betaD,date,datedc
 	use optim
-	
+
 	implicit none
-	
+
 	integer::m,i,j,ier,t,k,ns,mt1
 	double precision::lamR25,lamDC25,suR25,suDC25,lamR975,lamDC975,suR975,suDC975, &
-	LamRW,LamDCW,suRW,suDCW 
+	LamRW,LamDCW,suRW,suDCW
         double precision,dimension(m*(m+1)/2)::vv
 	double precision,dimension(m)::b,bgen
 	double precision,dimension(1000,m)::u
-	double precision::sx,som,x,zz,zy 
+	double precision::sx,som,x,zz,zy
 	double precision,dimension(1000):: lamR,lamDC,suR,suDC,glDC,glR
-	
+
 ! theorique - estimés après Max de Vrais
       double precision::glDCW,glRW
 
 	double precision,dimension(mt1)::x1R,x2DC
 	double precision,dimension(mt1,3)::moyLamR,moyLamDC
-		
+
 	double precision,dimension(100,3)::moysuR,moysuDC	
 	double precision,dimension(100)::xSu1,xSu2
 	double precision::ep
-	
-	
+
+
 	lamR25=0.d0
 	lamDC25=0.d0
 	suR25=0.d0
@@ -1227,7 +1457,7 @@
 	call dmfsdj(vv,m,ep,ier)
 
 	do k=1,1000
-		do j=1,ns   
+		do j=1,ns
 			call bgos(SX,0,zz,zy,0.d0)
 			u(k,j)=zz
 		end do
@@ -1245,7 +1475,7 @@
 	end if
 
 
-!============================ Surv strat 1	
+!============================ Surv strat 1
 !------------------- Pour les recurents
 !     Pour chaque temps de 0 à la censure du décès par pas cens/100
 !	x=-cens/100 !permet de commencer à 0 dans la boucle
@@ -1254,7 +1484,7 @@
 	do t=1,100
 
 		glR=0.d0
-		suR=0.d0  
+		suR=0.d0
 !         n=n+1 ! compteur sur nième temps
 		if (t.ne.1) then
 			x=x+cens/100
@@ -1292,15 +1522,15 @@
 			suR(k)  = dexp(-glR(k))
 			glRW  =  (x/(b(2)**2))**(b(1)**2)
 			suRW  = dexp(-glRW)
-			
+
 			if(nst == 2) then
 				glDC(k)  =  (x/bgen(4))**bgen(3)
 				suDC(k)  = dexp(-glDC(k))
 				glDCW  =  (x/(b(4)**2))**(b(3)**2)
-				suDCW  = dexp(-glDCW)	
+				suDCW  = dexp(-glDCW)
 			end if
 		end do
-	
+
 ! Classer les différent vecteur et en sortir les 2.5 et 97.5 percentiles
 		call percentile(lamR,lamR25,lamR975)
 		if(nst == 2) then
@@ -1311,7 +1541,7 @@
 		if(nst == 2) then
 			call percentile(suDC,suDC25,suDC975)
 		end if
-		
+
 		if(t == 1) then
 			x1R(t) = date(1)
 		else
@@ -1320,8 +1550,8 @@
 		moyLamR(t,1) = real(LamRW)
 		moyLamR(t,2) = real(lamR25)
 		moyLamR(t,3) = real(lamR975)
+
 		if(nst == 2) then
-			
 			x2DC(t) = x1R(t)
 			moyLamDC(t,1) = real(lamDCW)
 			moyLamDC(t,2) = real(lamDC25)
@@ -1336,19 +1566,19 @@
 		
 		moysuR(t,1) = real(suRW)
 		moysuR(t,2) = real(suR25)
-		moysuR(t,3) = real(suR975)	
+		moysuR(t,3) = real(suR975)
 		if(nst == 2) then
-			xSu2(t) = xSu1(t) 
+			xSu2(t) = xSu1(t)
 			moysuDC(t,1) = real(suDCW)
 			moysuDC(t,2) = real(suDC25)
 			moysuDC(t,3) = real(suDC975)
 		end if
-			
+
 	end do
 	if (nst == 1) then
 		moyLamDC = 0.d0
 		moysuDC = 0.d0
 	end if
 	end subroutine distanceJweib
-	
+
 
